@@ -1,5 +1,5 @@
-#include <kapp.h>
-#include <kstddirs.h>
+#include <tdeapplication.h>
+#include <kstandarddirs.h>
 
 #include <tdelocale.h>
 #include <tqbitmap.h>
@@ -30,7 +30,7 @@ TQPtrList<TQPixmap> *Status::loadPixmap(TQWidget *parent, TQString pixmapName,
 {
     if (pixmaps == NULL) {
         pixmaps = new TQPtrList<TQPixmap>;
-        pixmaps->setAutoDelete(TRUE);
+        pixmaps->setAutoDelete(true);
     }
 
     if (!pixmaps->isEmpty())
@@ -58,8 +58,8 @@ TQPtrList<TQPixmap> *Status::loadPixmap(TQWidget *parent, TQString pixmapName,
     for (int x = 0; x < PIXMAP.width()/width; x++) {
         TQPixmap *pixmap = new TQPixmap(width, height);
         pixmaps->append(pixmap);
-        bitBlt(pixmap, 0, 0, &PIXMAP, x*width, 0, width, height, CopyROP, TRUE);
-        bitBlt(&MASK, 0, 0, &BITMAP, x*width, 0, width, height, CopyROP, TRUE);
+        bitBlt(pixmap, 0, 0, &PIXMAP, x*width, 0, width, height, CopyROP, true);
+        bitBlt(&MASK, 0, 0, &BITMAP, x*width, 0, width, height, CopyROP, true);
         pixmap->setMask(MASK);
     }
 
@@ -123,7 +123,7 @@ TQString Status::decodeHexOctString(TQString s)
         value = s.mid(pos+leadin, 3);
         ptr = value.latin1();
 
-        while (*ptr != '\0' && (v = valids.find(*ptr++, 0, FALSE)) != -1) {
+        while (*ptr != '\0' && (v = valids.find(*ptr++, 0, false)) != -1) {
             c = (c * valids.length()) + v;
             len++;
         }
@@ -262,14 +262,14 @@ void Status::confScheme()
         newgroup.sprintf("Mode %d", mode);
         kapp->config()->setGroup(newgroup);     
 
-        confLevels(FALSE);
+        confLevels(false);
     }
 
     if (scheme != -1) {
         newgroup.sprintf("Scheme %d", scheme);
         kapp->config()->setGroup(newgroup);     
 
-        confLevels(FALSE);
+        confLevels(false);
     }
 
     kapp->config()->setGroup(oldgroup);
@@ -280,14 +280,14 @@ void Status::confScheme()
         newgroup.sprintf("Mode %d", mode);
         kapp->config()->setGroup(newgroup);     
 
-        confMisc(FALSE);
+        confMisc(false);
     }
 
     if (scheme != -1) {
         newgroup.sprintf("Scheme %d", scheme);
         kapp->config()->setGroup(newgroup);
 
-        confMisc(FALSE);
+        confMisc(false);
     }
 
     fillPixmapName(lifesPixmapName);
