@@ -51,7 +51,7 @@ public:
 
 protected:
     void confScheme();
-    void confMisc(bool defGroup=TRUE);
+    void confMisc(bool defGroup=true);
     void resizeEvent( TQResizeEvent * );
 
 private:
